// NP2Rnd - random NPS generator for Neuro-Programmer 2
//	(c) 2007 Sam C. Lin <lincomatic@hotmail.com>.  All Rights Reserved.
//	For latest version see http://www.geekmatica.com
//	Released under the GNU GPL version 2.
//	Use at your own risk.
//
//	" This program is free software; you can redistribute it and/or modify
//	  it under the terms of the GNU General Public License as published by
//	  the Free Software Foundation, version 2.
//	  
//	  This program is distributed in the hope that it will be useful,
//	  but WITHOUT ANY WARRANTY; without even the implied warranty of
//	  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	  GNU General Public License for more details. "
//
//	See the file COPYING for details of this license.
// 20070124 - SCL - creation
// 20070206 - SCL - fix bug, beatfreq parameter was being ignored.  Output
//    was hardcoded to 9-41Hz.


#include "stdafx.h"

#define BUFLEN 128

int IRnd(int min,int max)
{
  return rand() % (max-min+1) + min;
}

int main(int argc, char* argv[])
{
  printf("Lincomatic NP2 RND V1.1 %s %s\n",__DATE__,__TIME__);
  
  srand((unsigned)time(NULL));
  char s[BUFLEN];
  FILE *ifp = fopen("header.xml","r");
  FILE *ofp = fopen("rnd.nps","w");
  if (ifp) {
    while (fgets(s,BUFLEN,ifp)) {
      fputs(s,ofp);
    }
    fclose(ifp);
  }

  int minutes = 30;
  int bflo = 9;
  int bfhi = 41;
  int timelo = 1;
  int timehi = 5;
  int carriermin = 40;
  int carriermult = 2;//*9;

  if (argc > 1) {
    for (int i=1;i < argc;i++) {
      if (!strncmp(argv[i],"--beatfreq:",11)) {
	sscanf(argv[i]+11,"%d:%d",&bflo,&bfhi);
      }
      else if (!strncmp(argv[i],"--seglen:",9)) {
	sscanf(argv[i]+9,"%d:%d",&timelo,&timehi);
      }
      else if (!strncmp(argv[i],"--carrier:",10)) {
	sscanf(argv[i]+10,"%d:%d",&carriermin,&carriermult);
      }
      else if (!strncmp(argv[i],"--minutes:",10)) {
	sscanf(argv[i]+10,"%d",&minutes);
      }
      else {
	printf("Usage: %s [options]\n",argv[0]);
	printf("  --beatfreq:beatfreqmin:beatfreqmax (default: --beatfreq:9:41)\n");
	printf("  --carrier:carriermin:carriermult -> carrier = carriermin + beatfreq * carriermult\n");
	printf("         (default: --carrier:40:2\n");
	printf("  --minutes:sessionlength (default: --minutes:30\n");
	printf("  --seglen:secondsmin:secondsmax (default: --seglen:1:5)\n");
	printf("outputs to rnd.nps\n");
	return 1;
      }
    }
  }

  printf("session length: %d minutes\n",minutes);
  printf("Beat Frequency: %d->%d Hz\n",bflo,bfhi);
  printf("Segment length %d->%d seconds\n",timelo,timehi);
  printf("Carrier: %d",carriermin);
  if (carriermult) {
    printf(" + beatfreq * %d",carriermult);
  }
  printf(" Hz\n");



  bflo *= 10;
  bfhi *= 10;
   

  fprintf(ofp,"<length>%d</length>\n",minutes);
  fprintf(ofp,"  <id>23186322</id>\n");
  fprintf(ofp,"  <type>0</type>\n");
  fprintf(ofp,"  <importedBWT />\n");
  fprintf(ofp,"  <headphones_required>true</headphones_required>\n");
  fprintf(ofp,"  <playtoinfinity>false</playtoinfinity>\n");
  fprintf(ofp,"  <misc />\n");
  fprintf(ofp,"</SessionOptions>\n");

  float otime = 0;
  while (otime < minutes) {
    float beatfreq = (float)(((float)IRnd(bflo,bfhi))/10.0);
    float carrier = carriermin + beatfreq*carriermult;
    fprintf(ofp,"<track0_points>\n");
    fprintf(ofp,"  <graphpoint>%0.6f</graphpoint>\n",beatfreq);
    fprintf(ofp,"  <lowpass_wave>200</lowpass_wave>\n");
    fprintf(ofp,"  <time>%0.6f</time>\n",otime);
    fprintf(ofp,"  <ramp>false</ramp>\n");
    fprintf(ofp,"  <invert>false</invert>\n");
    fprintf(ofp,"  <volume>300</volume>\n");
    fprintf(ofp,"  <tonevolume>300</tonevolume>\n");
    fprintf(ofp,"  <mod_intensity>0</mod_intensity>\n");
    fprintf(ofp,"  <pulse_intensity>1000</pulse_intensity>\n");
    fprintf(ofp,"  <panmod_intensity>0</panmod_intensity>\n");
    fprintf(ofp,"  <lowpass_intensity>100</lowpass_intensity>\n");
    fprintf(ofp,"  <freqmod_intensity>0</freqmod_intensity>\n");
    fprintf(ofp,"  <pitch>%0.6f</pitch>\n",carrier);
    fprintf(ofp,"  <edit_pitch>false</edit_pitch>\n");
    fprintf(ofp,"</track0_points>\n");

    fprintf(ofp,"<track1_points>\n");
    fprintf(ofp,"  <graphpoint>%0.6f</graphpoint>\n",beatfreq);
    fprintf(ofp,"  <lowpass_wave>0</lowpass_wave>\n");
    fprintf(ofp,"  <time>%0.6f</time>\n",otime);
    fprintf(ofp,"  <ramp>false</ramp>\n");
    fprintf(ofp,"  <invert>false</invert>\n");
    fprintf(ofp,"  <volume>1000</volume>\n");
    fprintf(ofp,"  <tonevolume>1000</tonevolume>\n");
    fprintf(ofp,"  <mod_intensity>0</mod_intensity>\n");
    fprintf(ofp,"  <pulse_intensity>250</pulse_intensity>\n");
    fprintf(ofp,"  <panmod_intensity>0</panmod_intensity>\n");
    fprintf(ofp,"  <lowpass_intensity>100</lowpass_intensity>\n");
    fprintf(ofp,"  <freqmod_intensity>0</freqmod_intensity>\n");
    fprintf(ofp,"  <pitch>168.4211</pitch>\n");
    fprintf(ofp,"  <edit_pitch>false</edit_pitch>\n");
    fprintf(ofp,"</track1_points>\n");


    int secs = IRnd(timelo,timehi);
    otime += (float)(((float)secs)/60.0);

    printf("%6.1f %4.1f %d\n",carrier,beatfreq,secs);
  }


fprintf(ofp,"<track0_options>\n");
fprintf(ofp,"  <name>Tones1</name>\n");
fprintf(ofp,"  <highgraphpoint>42</highgraphpoint>\n");
fprintf(ofp,"  <lowgraphpoint>0</lowgraphpoint>\n");
fprintf(ofp,"  <highgraphlimit>100</highgraphlimit>\n");
fprintf(ofp,"  <lowgraphlimit>0</lowgraphlimit>\n");
fprintf(ofp,"  <highpoint>16</highpoint>\n");
fprintf(ofp,"  <lowpoint>8</lowpoint>\n");
fprintf(ofp,"  <highfreq>20</highfreq>\n");
fprintf(ofp,"  <lowfreq>1</lowfreq>\n");
fprintf(ofp,"  <hightone>180</hightone>\n");
fprintf(ofp,"  <lowtone>180</lowtone>\n");
fprintf(ofp,"  <tracklength>100</tracklength>\n");
fprintf(ofp,"  <showtime>%d</showtime>\n",minutes);
fprintf(ofp,"  <balance>0</balance>\n");
fprintf(ofp,"  <default_volume>300</default_volume>\n");
fprintf(ofp,"  <default_tone_volume>300</default_tone_volume>\n");
fprintf(ofp,"  <default_mod_intensity>0</default_mod_intensity>\n");
fprintf(ofp,"  <default_pulse_intensity>1000</default_pulse_intensity>\n");
fprintf(ofp,"  <default_panmod_intensity>0</default_panmod_intensity>\n");
fprintf(ofp,"  <default_lowpass_intensity>100</default_lowpass_intensity>\n");
fprintf(ofp,"  <default_freqmod_intensity>0</default_freqmod_intensity>\n");
fprintf(ofp,"  <default_lowpass_wave>200</default_lowpass_wave>\n");
fprintf(ofp,"  <default_ramp>true</default_ramp>\n");
fprintf(ofp,"  <default_invert>true</default_invert>\n");
fprintf(ofp,"  <wavetype>0</wavetype>\n");
fprintf(ofp,"  <noisecolor>2</noisecolor>\n");
fprintf(ofp,"  <noiseoption>0</noiseoption>\n");
fprintf(ofp,"  <backgroundfile />\n");
fprintf(ofp,"  <iso_wavetype>1</iso_wavetype>\n");
fprintf(ofp,"  <required>false</required>\n");
fprintf(ofp,"  <muted_by_default>false</muted_by_default>\n");
fprintf(ofp,"  <muted>false</muted>\n");
fprintf(ofp,"  <tracktype>2</tracktype>\n");
fprintf(ofp,"  <tonetype>2</tonetype>\n");
fprintf(ofp,"  <oncolor>0</oncolor>\n");
fprintf(ofp,"  <offcolor>0</offcolor>\n");
fprintf(ofp,"  <phase>90</phase>\n");
fprintf(ofp,"  <smooth_background_time>0</smooth_background_time>\n");
fprintf(ofp,"  <smooth_background>false</smooth_background>\n");
fprintf(ofp,"</track0_options>\n");




fprintf(ofp,"<track1_options>\n");
fprintf(ofp,"  <name>AudioStrobe1</name>\n");
fprintf(ofp,"  <highgraphpoint>42</highgraphpoint>\n");
fprintf(ofp,"  <lowgraphpoint>0</lowgraphpoint>\n");
fprintf(ofp,"  <highgraphlimit>100</highgraphlimit>\n");
fprintf(ofp,"  <lowgraphlimit>0</lowgraphlimit>\n");
fprintf(ofp,"  <highpoint>16</highpoint>\n");
fprintf(ofp,"  <lowpoint>8</lowpoint>\n");
fprintf(ofp,"  <highfreq>20</highfreq>\n");
fprintf(ofp,"  <lowfreq>1</lowfreq>\n");
fprintf(ofp,"  <hightone>200</hightone>\n");
fprintf(ofp,"  <lowtone>100</lowtone>\n");
fprintf(ofp,"  <tracklength>100</tracklength>\n");
fprintf(ofp,"  <showtime>%d</showtime>\n",minutes);
fprintf(ofp,"  <balance>0</balance>\n");
fprintf(ofp,"  <default_volume>1000</default_volume>\n");
fprintf(ofp,"  <default_tone_volume>500</default_tone_volume>\n");
fprintf(ofp,"  <default_mod_intensity>0</default_mod_intensity>\n");
fprintf(ofp,"  <default_pulse_intensity>250</default_pulse_intensity>\n");
fprintf(ofp,"  <default_panmod_intensity>0</default_panmod_intensity>\n");
fprintf(ofp,"  <default_lowpass_intensity>100</default_lowpass_intensity>\n");
fprintf(ofp,"  <default_freqmod_intensity>0</default_freqmod_intensity>\n");
fprintf(ofp,"  <default_lowpass_wave>0</default_lowpass_wave>\n");
fprintf(ofp,"  <default_ramp>true</default_ramp>\n");
fprintf(ofp,"  <default_invert>false</default_invert>\n");
fprintf(ofp,"  <wavetype>0</wavetype>\n");
fprintf(ofp,"  <noisecolor>2</noisecolor>\n");
fprintf(ofp,"  <noiseoption>0</noiseoption>\n");
fprintf(ofp,"  <backgroundfile />\n");
fprintf(ofp,"  <iso_wavetype>0</iso_wavetype>\n");
fprintf(ofp,"  <required>true</required>\n");
fprintf(ofp,"  <muted_by_default>false</muted_by_default>\n");
fprintf(ofp,"  <muted>false</muted>\n");
fprintf(ofp,"  <tracktype>3</tracktype>\n");
fprintf(ofp,"  <tonetype>2</tonetype>\n");
fprintf(ofp,"  <oncolor>-3217409</oncolor>\n");
fprintf(ofp,"  <offcolor>-16777216</offcolor>\n");
fprintf(ofp,"  <phase>90</phase>\n");
fprintf(ofp,"  <smooth_background_time>0.6</smooth_background_time>\n");
fprintf(ofp,"  <smooth_background>true</smooth_background>\n");
fprintf(ofp,"  </track1_options>\n");


fprintf(ofp,"</npsession>\n");

  fflush(ofp);
  fclose(ofp);

  return 0;
}

